summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcylinderedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcylinderedit.h')
-rw-r--r--kpovmodeler/pmcylinderedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmcylinderedit.h b/kpovmodeler/pmcylinderedit.h
index 9b25ec2a..0444c120 100644
--- a/kpovmodeler/pmcylinderedit.h
+++ b/kpovmodeler/pmcylinderedit.h
@@ -38,9 +38,9 @@ class PMCylinderEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMCylinderEdit with tqparent and name
*/
- PMCylinderEdit( TQWidget* tqparent, const char* name = 0 );
+ PMCylinderEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,9 +38,9 @@ class PMCylinderEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMCylinderEdit with tqparent and name
+ * Creates a PMCylinderEdit with parent and name
*/